From e3e1f6308d4636b546798f6aa2f7624b8dc52c9e Mon Sep 17 00:00:00 2001
From: Diva Canto
Date: Thu, 9 Jun 2011 16:11:47 -0700
Subject: Change the name of the newest command to "show names" so that it
 doesn't conflict with the existing "show users"

---
 .../CoreModules/Framework/UserManagement/UserManagementModule.cs      | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/OpenSim/Region/CoreModules/Framework/UserManagement/UserManagementModule.cs b/OpenSim/Region/CoreModules/Framework/UserManagement/UserManagementModule.cs
index ae4336c..accd094 100644
--- a/OpenSim/Region/CoreModules/Framework/UserManagement/UserManagementModule.cs
+++ b/OpenSim/Region/CoreModules/Framework/UserManagement/UserManagementModule.cs
@@ -82,8 +82,8 @@ namespace OpenSim.Region.CoreModules.Framework.UserManagement
             //    }
             //}
             MainConsole.Instance.Commands.AddCommand("grid", true,
-                "show user-names",
-                "show user-names",
+                "show names",
+                "show names",
                 "Show the bindings between user UUIDs and user names",
                 String.Empty,
                 HandleShowUsers);
-- 
cgit v1.1


From 8d3a8a0a8150e856103a152228b736ab74f821d7 Mon Sep 17 00:00:00 2001
From: Diva Canto
Date: Thu, 9 Jun 2011 16:51:47 -0700
Subject: The map breakage is actually at 2048!

---
 OpenSim/Region/CoreModules/World/WorldMap/WorldMapModule.cs | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/OpenSim/Region/CoreModules/World/WorldMap/WorldMapModule.cs b/OpenSim/Region/CoreModules/World/WorldMap/WorldMapModule.cs
index 30cf1db..69d3005 100644
--- a/OpenSim/Region/CoreModules/World/WorldMap/WorldMapModule.cs
+++ b/OpenSim/Region/CoreModules/World/WorldMap/WorldMapModule.cs
@@ -209,16 +209,16 @@ namespace OpenSim.Region.CoreModules.World.WorldMap
             //                  path, param, agentID.ToString());
 
             // There is a major hack going on in this method. The viewer doesn't request
             // map blocks (RequestMapBlocks) above 4096. That means that if we don't hack,
             // grids above that cell don't have a map at all. So, here's the hack: we wait
             // for this CAP request to come, and we inject the map blocks at this point. 
             // In a normal scenario, this request simply sends back the MapLayer (the blue color).
             // In the hacked scenario, it also sends the map blocks via UDP.
             //
             // 6/8/2011 -- I'm adding an explicit 4096 check, so that we never forget that there is
             // a hack here, and so that regions below 4096 don't get spammed with unnecessary map blocks.
 
-            if (m_scene.RegionInfo.RegionLocX >= 4096 || m_scene.RegionInfo.RegionLocY >= 4096)
+            if (m_scene.RegionInfo.RegionLocX >= 2048 || m_scene.RegionInfo.RegionLocY >= 2048)
             {
                 ScenePresence avatarPresence = null;
 
@@ -209,16 +209,16 @@ namespace OpenSim.Region.CoreModules.World.WorldMap
 
             // There is a major hack going on in this method. The viewer doesn't request
-            // map blocks (RequestMapBlocks) above 4096. That means that if we don't hack,
+            // map blocks (RequestMapBlocks) above 2048. That means that if we don't hack,
             // grids above that cell don't have a map at all. So, here's the hack: we wait
             // for this CAP request to come, and we inject the map blocks at this point. 
@@ -209,16 +209,16 @@ namespace OpenSim.Region.CoreModules.World.WorldMap
             // In the hacked scenario, it also sends the map blocks via UDP.
             //
-            // 6/8/2011 -- I'm adding an explicit 4096 check, so that we never forget that there is
+            // 6/8/2011 -- I'm adding an explicit 2048 check, so that we never forget that there is
             // a hack here, and so that regions below 4096 don't get spammed with unnecessary map blocks.
 
-- 
cgit v1.1